package com.datacloudsec.utils;

import com.datacloudsec.exception.UEException;
import com.datacloudsec.scan.common.Constant;
import com.datacloudsec.scan.entity.Task;
import com.datacloudsec.scan.service.IConfig;
import com.datacloudsec.scan.service.IReport;
import com.datacloudsec.scan.service.impl.ConfigService;
import com.datacloudsec.scan.service.impl.ReportService;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import com.datacloudsec.utils.ZipUtil;
import it.sauronsoftware.ftp4j.FTPClient;
import it.sauronsoftware.ftp4j.FTPFile;
import java.io.File;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;
import org.apache.commons.io.FileUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.log4j.Logger;

public class FtpUtil {

   private static final Logger LOG = Logger.getLogger(FtpUtil.class);
   private static IConfig configService = (IConfig)InstanceUtil.newServiceInstance(ConfigService.class);
   private static IReport reportService = (IReport)InstanceUtil.newServiceInstance(ReportService.class);


   public static FTPClient newFTPClient(String ip, String user, String password) {
      FTPClient client = new FTPClient();

      try {
         client.connect(ip, 21);
      } catch (Exception var6) {
         throw new UEException("文件服务器连接失败", var6);
      }

      try {
         client.login(user, password);
         client.setType(2);
         client.setCharset("gbk");
         return client;
      } catch (Exception var5) {
         throw new UEException("文件服务器登录失败", var5);
      }
   }

   public static FTPClient newFTPClient(String ip, int port, String user, String password) {
      FTPClient client = new FTPClient();

      try {
         client.connect(ip, port);
      } catch (Exception var7) {
         throw new UEException("文件服务器连接失败", var7);
      }

      try {
         client.login(user, password);
         client.setType(2);
         client.setCharset("gbk");
         return client;
      } catch (Exception var6) {
         throw new UEException("文件服务器登录失败", var6);
      }
   }

   public static void closeFTPClient(FTPClient client) {
      if(client != null) {
         try {
            client.disconnect(true);
         } catch (Exception var2) {
            ;
         }
      }

   }

   public static void mkdirs(FTPClient client, String dir) throws Exception {
      if(dir != null) {
         dir = dir.replace("//", "/");
         String[] dirs = dir.split("/");

         for(int i = 0; i < dirs.length; ++i) {
            dir = dirs[i];
            if(!StringUtils.isEmpty(dir)) {
               if(!exists(client, dir)) {
                  client.createDirectory(dir);
               }

               client.changeDirectory(dir);
            }
         }

      }
   }

   public static boolean exists(FTPClient client, String dir) throws Exception {
      return getFileType(client, dir) != -1;
   }

   private static int getFileType(FTPClient client, String dir) throws Exception {
      FTPFile[] files = null;

      try {
         files = client.list(dir);
      } catch (Exception var8) {
         return -1;
      }

      if(files.length > 1) {
         return 1;
      } else if(files.length == 1) {
         FTPFile e = files[0];
         if(e.getType() == 1) {
            return 1;
         } else {
            String path = dir + "/" + e.getName();

            try {
               int e1 = client.list(path).length;
               return e1 == 1?1:0;
            } catch (Exception var6) {
               return 0;
            }
         }
      } else {
         try {
            client.changeDirectory(dir);
            client.changeDirectoryUp();
            return 1;
         } catch (Exception var7) {
            return -1;
         }
      }
   }

   public static void reportUpload(Task task, Map device, String chkType, String reportType) throws Exception {
      if(task.getVal1() != null && task.getVal1().intValue() == 1) {
         FTPClient client = null;
         File ftpfile = null;

         try {
            String e = configService.getValueByName("ftp_ip");
            String ftp_username = configService.getValueByName("ftp_username");
            String ftp_password = configService.getValueByName("ftp_password");
            String ftp_file_path = configService.getValueByName("ftp_file_path");
            int ftp_port = ObjectUtil.getInt(configService.getValueByName("ftp_port"), 21);
            client = newFTPClient(e, ftp_port, ftp_username, ftp_password);
            if(StringUtils.isNotBlank(ftp_file_path)) {
               client.changeDirectory(ftp_file_path);
            }

            String expname = task.getName() + "_" + ObjectUtil.getString(device.get("name"), "").replace(".", "-").replaceAll("[\\s\\\\/:\\*\\?\\\"<>\\|]", "");
            String filename = reportService.export(ObjectUtil.getString(device.get("id"), ""), expname, StringUtils.isBlank(task.getFtpReportType())?"html":task.getFtpReportType(), chkType, reportType, (String)null, (String)null, (String)null, (String)null, (String)null, (String)null);
            File f = new File(Constant.REPORT_LIST, filename);
            ftpfile = new File(Constant.WORK_DIR, expname + "_" + task.getFtpReportType() + ".zip");
            FileUtils.copyFile(f, ftpfile);
            client.setType(2);
            client.setCharset("UTF-8");
            client.upload(ftpfile);
         } catch (Exception var17) {
            LOG.error("FTP上传文件异常", var17);
         } finally {
            closeFTPClient(client);
            if(ftpfile != null && ftpfile.exists()) {
               ftpfile.delete();
            }

         }
      }

   }

   public static void sendReport(Task task, String devids, String chkType, String reportType) throws Exception {
      FTPClient client = null;
      File ftpfile = null;

      try {
         String e = configService.getValueByName("ftp_ip");
         String ftp_username = configService.getValueByName("ftp_username");
         String ftp_password = configService.getValueByName("ftp_password");
         String ftp_file_path = configService.getValueByName("ftp_file_path");
         int ftp_port = ObjectUtil.getInt(configService.getValueByName("ftp_port"), 21);
         client = newFTPClient(e, ftp_port, ftp_username, ftp_password);
         if(StringUtils.isNotBlank(ftp_file_path)) {
            client.changeDirectory(ftp_file_path);
         }

         String expname = task.getName().trim().replace(".", "-").replaceAll("(\"|<|>|(\\|)|/|\\\\|\\*|\\?|:)", "");
         String filename = reportService.export(devids, expname, StringUtils.isBlank(task.getFtpReportType())?"html":task.getFtpReportType(), chkType, reportType, (String)null, (String)null, (String)null, (String)null, (String)null, (String)null);
         File f = new File(Constant.REPORT_LIST, filename);
         if("xls".equals(task.getFtpReportType())) {
            ftpfile = new File(Constant.WORK_DIR, expname + "_" + task.getFtpReportType() + ".zip");
            ZipUtil.toZip(ftpfile, new File[]{f}, (String)null);
         } else {
            ftpfile = new File(Constant.WORK_DIR, expname + "_" + task.getFtpReportType() + ".zip");
            FileUtils.copyFile(f, ftpfile);
         }

         client.setType(2);
         client.setCharset("UTF-8");
         client.upload(ftpfile);
      } catch (Exception var17) {
         LOG.error("FTP上传文件异常", var17);
      } finally {
         closeFTPClient(client);
         if(ftpfile != null && ftpfile.exists()) {
            ftpfile.delete();
         }

      }

   }

   public static void main(String[] args) throws Exception {
      FTPClient client = null;

      try {
         client = newFTPClient("192.168.0.212", "root", "rtfkqkhh");
         String[] var5;
         int var4 = (var5 = client.listNames()).length;

         for(int dateStr = 0; dateStr < var4; ++dateStr) {
            String sdf = var5[dateStr];
            System.out.println("-- " + sdf);
         }

         SimpleDateFormat var9 = new SimpleDateFormat("yyyy//MM");
         String var10 = var9.format(new Date());
         mkdirs(client, var10);
         System.out.println("当前目录：" + client.currentDirectory());
      } finally {
         closeFTPClient(client);
      }
   }
}
